#
# Copyright (c) 2023, HILSTER - https://hilster.io
# All rights reserved.
#
from typing import Union, List

from htf.checksum.core import CRC as _CRC


class CRC(_CRC):
    """
    A configurable CRC calculator.
    """

    def __init__(
        self,
        width: int,
        polynomial: int,
        reflect_input: bool,
        initial_value: int,
        reflect_output: bool,
        xor_output: int,
    ) -> None:
        """
        The CRC constructor.

        Args:
            width: the CRC's width in bits
            polynomial: the CRC's polynomial
            reflect_input: if set to ``True`` input is reflected
            initial_value: the initial value
            reflect_output: if set to ``True`` output is reflected
            xor_output: xor all outputs with ``xor_output``
        """
        super(CRC, self).__init__(
            width=width,
            polynomial=polynomial,
            reflect_input=reflect_input,
            initial_value=initial_value,
            reflect_output=reflect_output,
            xor_output=xor_output,
        )

    def calculate(self, data: Union[str, bytes, List[int]]) -> int:
        """
        Calculates the crc over ``data`` bit by bit.

        Arguments:
            data: the input data to be used for
                the crc calculation

        Returns:
            int: the calculated crc for ``data``
        """
        return super(CRC, self).calculate(data=data)
